;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "ansi" "20251118.230"
  "Turn string into ansi strings."
  '((emacs  "24.1")
    (cl-lib "0.6"))
  :url "http://github.com/rejeep/ansi"
  :commit "a3aa9daa37a75fec22186399014a790a6c554311"
  :revdesc "a3aa9daa37a7"
  :keywords '("terminals" "color" "ansi")
  :authors '(("Johan Andersson" . "johan.rejeep@gmail.com"))
  :maintainers '(("Johan Andersson" . "johan.rejeep@gmail.com")))
